# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/EDTravelCompanion',
                'doc_host': 'https://fenke.github.io',
                'git_url': 'https://github.com/fenke/EDTravelCompanion',
                'lib_path': 'edcompanion'},
  'syms': { 'edcompanion.core': {'edcompanion.core.foo': ('core.html#foo', 'edcompanion/core.py')},
            'edcompanion.eddb.navigation': { 'edcompanion.eddb.navigation.navigationroute': ( 'eddb/navroute.html#navigationroute',
                                                                                              'edcompanion/eddb/navigation.py')},
            'edcompanion.linalg.fitsvd': { 'edcompanion.linalg.fitsvd.fitline': ( 'linalg/linalg_fitsvd.html#fitline',
                                                                                  'edcompanion/linalg/fitsvd.py')},
            'edcompanion.md.edastro': { 'edcompanion.md.edastro.create_galaxymap_url': ( 'md/edastro.html#create_galaxymap_url',
                                                                                         'edcompanion/md/edastro.py'),
                                        'edcompanion.md.edastro.embed_galaxymap': ( 'md/edastro.html#embed_galaxymap',
                                                                                    'edcompanion/md/edastro.py')}}}
